@@ -265,6 +265,7 @@ class DynamicHTMLParser(XSSTemplateParser):
         for tag in tags:
             href = tag.attrib.get(attribute)
             matches = glob.glob(os.path.join(self.path, href))
+            matches.sort()
             if len(matches):
                 self.expand_tag(tag, matches, attribute)
 
@@ -282,7 +283,7 @@ class DynamicHTMLParser(XSSTemplateParser):
 
         # process possible resource globbing
         self.glob_resources(
-            root, "href", './/link')
+            root, "href", './/link[@type]')
         self.glob_resources(
             root, "src", './/script')
 
@@ -357,7 +358,7 @@ class DynamicHTMLParser(XSSTemplateParser):
 
         # prepare reference rebase logic
         elements = root.xpath(
-            './/link[@href] | .//img[@src] | .//script[@src]')
+            './/link[@type and @href] | .//img[@src] | .//script[@src]')
         for element in elements:
             href = element.attrib.get('href')
             if href is not None:
